# Image Credits

Example images in this directory are from open-access scientific publications
licensed under [Creative Commons Attribution 4.0 (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/).

## Sources

- `example_genetics.png` - Figure 1 from [doi:10.1038/s41588-025-02336-6](https://doi.org/10.1038/s41588-025-02336-6), *Nature Genetics* (2025). License: CC BY 4.0

- `example_potency.png` - Figure 1 from [doi:10.1038/s41592-025-02857-2](https://doi.org/10.1038/s41592-025-02857-2), *Nature Methods* (2025). License: CC BY 4.0

- `example_multiomics.png` - Figure 1 from [doi:10.1038/s41592-025-02856-3](https://doi.org/10.1038/s41592-025-02856-3), *Nature Methods* (2025). License: CC BY 4.0
